import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Button, Notify, Field, Cell, CellGroup } from '@antmjs/vantui';
import LocType from '@/components/locType';
import IssueType from '@/components/issueType';
import Map from '@/components/map';
import Uploader from '@/components/Uploader/index';
import { getIssueStatus } from '@/utils/biz';
import mapIcon from '@/assets/icons/marker.png';

export default (props) => {
  const { issue, readOnly, renderFields, renderAction } = props;

  const [formData, setFormData] = React.useState({
    typeId: undefined,
    typeName: undefined,
    locId: undefined,
    locName: undefined,
    location: undefined,
    addr: undefined,
    content: undefined,
    attachList: [],
  });
  const [showLocType, setShowLocType] = React.useState(false);
  const [showIssueType, setShowIssueType] = React.useState(false);
  const [bizStatus, setBizStatus] = React.useState();
  
  const onLocTypeChange = (_, it) => {
    setFormData({
      ...formData,
      locId: it.typeId,
      locName: it.name,
    });
    setShowLocType(false);
  }

  const onIssueTypeChange = (_, it) => {
    setFormData({
      ...formData,
      typeId: it.typeId,
      typeName: it.name,
    });
    setShowIssueType(false);
  }

  const onFieldChange = (field, value) => {
    setFormData({
      ...formData,
      [field]: value,
    })
  }

  React.useEffect(() => {
    if (issue) {
      setFormData(issue);
      setBizStatus(getIssueStatus(issue));
    }
  }, [issue]);
  
  return (
    <View>
      <LocType
        show={showLocType}
        value={formData.addr}
        onCancel={() => setShowLocType(false)}
        onChange={onLocTypeChange}
      />

      <IssueType
        show={showIssueType}
        value={formData.typeName}
        onCancel={() => setShowIssueType(false)}
        onChange={onIssueTypeChange}
      />

      <Map location={formData.location} />

      <CellGroup>
        <Cell
          title="点位"
          isLink={!readOnly}
          value={formData.locName}
          onClick={() => !readOnly && setShowLocType(true)}
        />
        <Field
          placeholder="请输入地址"
          value={formData.addr}
          leftIcon={mapIcon}
          readonly={readOnly}
          onChange={e => onFieldChange('addr', e.detail)}
        />
      </CellGroup>

      {
        readOnly && bizStatus && (
          <CellGroup style={{marginTop: '20px'}}>
            <Cell
              title="状态"
              value={bizStatus.label}
            />
          </CellGroup>
        )
      }

      <CellGroup style={{marginTop: '20px'}}>
        <Cell
          title="问题分类"
          isLink={!readOnly}
          style={{marginTop: '20px'}}
          value={formData.typeName}
          onClick={() => !readOnly && setShowIssueType(true)}
        />
        <Cell title="问题描述" border={false} />

        <Field
          type="textarea"
          placeholder="请输入问题描述"
          readonly={readOnly}
          autosize={{ minHeight: '120px' }}
          value={formData.content}
          onChange={e => onFieldChange('content', e.detail)}
        />
      </CellGroup>
            
      <CellGroup style={{marginTop: '20px'}}>        
        <Cell title="拍照或视频" border={false} />

        <Cell
          renderTitle={
            <Uploader
              value={formData.attachList}
              disabled={readOnly}
              onChange={e => onFieldChange('attachList',e)}
            />
          }
        />
      </CellGroup>

      {
        renderFields ? renderFields(formData, setFormData) : null
      }

      {
        renderAction ? (
          <View style={{margin: '20px auto'}}>
            {renderAction(formData)}
          </View>
        ) : null
      }
    </View>
  )
}
